@@ -188,8 +188,8 @@ class VeracodeAPI:
     def get_user_by_name(self,username):
         return Users().get_by_name(username)
 
-    def create_user (self,email,firstname,lastname,username=None,type="HUMAN",roles=[],teams=[]):
-        return Users().create(email,firstname,lastname,username,type,roles,teams)
+    def create_user (self,email,firstname,lastname,username=None,type="HUMAN",roles=[],teams=[],mfa=False):
+        return Users().create(email,firstname,lastname,username,type,roles,teams,mfa=mfa)
 
     def update_user_roles (self,user_guid,roles):
         return Users().update_roles(user_guid,roles)
@@ -274,6 +274,12 @@ class VeracodeAPI:
     def get_project(self,workspace_guid,project_guid):
         return Workspaces().get_project(workspace_guid,project_guid)
 
+    def get_project_issues(self,workspace_guid,project_guid):
+        return Workspaces().get_project_issues(workspace_guid,project_guid)
+
+    def get_project_libraries(self,workspace_guid,project_guid):
+        return Workspaces().get_project_libraries(workspace_guid,project_guid)
+
     def get_agents(self,workspace_guid):
         return Workspaces().get_agents(workspace_guid)
 
